# -*- coding: utf-8 -*-
#
# ??XMESSHandler?? - XMESS Application lirc creator
#
# Copyright (C) 2007, Don Smith, Mario Limonciello, for Mythbuntu
#
#
# Mythbuntu is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3 of the License, or at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this application; if not, write to the Free Software Foundation, Inc., 51
# Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
##################################################################################

from MythbuntuLircGenerator.core import ProgramHandler

class XMESSHandler(ProgramHandler):
    def __init__(self,lircd, lircrc,repeat,delay):
        application_name="xmess"
        application_dictionary={ \
        "up":"103", \
        "down":"108", \
        "left":"105", \
        "right":"106", \
        "enter":"28", \
        "vol-":"108", \
        "vol+":"103", \
        "ok":"28", \
        "home":"41", \
        "menu":"41", \
        "pause":"25", \
        "play":"25", \
        "stop":"1", \
        "exit":"1", \
        "one":"2", \
        "two":"3", \
        "five":"6", \
        "six":"7", \
        }
        ProgramHandler.__init__(self,application_name,application_dictionary,lircd,lircrc,repeat,delay)
